+++
title = "Output HTML and JSON"
outputs = ["html", "json"]
tags = ["outputs", "json"]
draft = false
+++

**Note**: A `single.json` is required to be at a valid location in the
template lookup hierarchy for the JSON outputs to be created.

[Here's the JSON output version of this page](./index.json).
